% TestCheckJavaPath define test cases for bfCheckJavaPath utility function
%
% Require MATLAB xUnit Test Framework to be installed
% http://www.mathworks.com/matlabcentral/fileexchange/22846-matlab-xunit-test-framework

% OME Bio-Formats package for reading and converting biological file formats.
%
% Copyright (C) 2012 - 2013 Open Microscopy Environment:
%   - Board of Regents of the University of Wisconsin-Madison
%   - Glencoe Software, Inc.
%   - University of Dundee
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as
% published by the Free Software Foundation, either version 2 of the
% License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License along
% with this program; if not, write to the Free Software Foundation, Inc.,
% 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.


classdef TestCheckJavaPath < TestBfMatlab
    
    properties
        status
    end
    
    methods
        function self = TestCheckJavaPath(name)
            self = self@TestBfMatlab(name);
        end
        
        function testDefault(self)
            self.status = bfCheckJavaPath();
            assertTrue(self.status);
        end
        
        function testAutoloadBioformats(self)
            self.status = bfCheckJavaPath(true);
            assertTrue(self.status);
        end
        
        function testNoAutoloadBioformats(self)
            isStatic = ismember(self.lociToolsPath,...
                javaclasspath('-static'));
            self.status = bfCheckJavaPath(false);
            if isStatic
                assertTrue(self.status);
            else
                assertFalse(self.status);
            end
        end
        
        function testPerformance(self)
            maxTime = .5;
            tic;
            self.status = bfCheckJavaPath();
            totalCheckTime=toc;
            assert(totalCheckTime<maxTime);
        end
    end
end